import React, { useCallback } from 'react';
import useField from '../../useField';
import withCondition from '../../withCondition';
import Label from '../../Label';
import Error from '../../Error';
import { text } from '../../../../../fields/validations';
import FieldDescription from '../../FieldDescription';
import './index.scss';
const Text = (props) => {
    const { path: pathFromProps, name, required, validate = text, label, admin: { placeholder, readOnly, style, width, description, condition, } = {}, value: valueFromProps, onChange: onChangeFromProps, } = props;
    const path = pathFromProps || name;
    const fieldType = useField({
        path,
        validate,
        enableDebouncedValue: true,
        condition,
    });
    const { value: valueFromContext, showError, setValue, errorMessage, } = fieldType;
    const onChange = useCallback((e) => {
        const { value: incomingValue } = e.target;
        if (typeof onChangeFromProps === 'function') {
            onChangeFromProps(incomingValue);
        }
        else {
            setValue(e);
        }
    }, [
        onChangeFromProps,
        setValue,
    ]);
    const classes = [
        'field-type',
        'text',
        showError && 'error',
        readOnly && 'read-only',
    ].filter(Boolean).join(' ');
    const value = valueFromProps || valueFromContext || '';
    return (React.createElement("div", { className: classes, style: {
            ...style,
            width,
        } },
        React.createElement(Error, { showError: showError, message: errorMessage }),
        React.createElement(Label, { htmlFor: path, label: label, required: required }),
        React.createElement("input", { value: value, onChange: onChange, disabled: readOnly, placeholder: placeholder, type: "text", id: path, name: path }),
        React.createElement(FieldDescription, { value: value, description: description })));
};
export default withCondition(Text);
